@@ -233,6 +233,9 @@ procman_data_new (GSettings *settings)
 
     pd->config.width = g_settings_get_int (settings, "width");
     pd->config.height = g_settings_get_int (settings, "height");
+    pd->config.xpos = g_settings_get_int (settings, "x-position");
+    pd->config.ypos = g_settings_get_int (settings, "y-position");
+
     pd->config.show_tree = g_settings_get_boolean (settings, "show-tree");
     g_signal_connect (G_OBJECT(settings), "changed::show-tree", G_CALLBACK(tree_changed_cb), pd);
 
@@ -445,7 +448,7 @@ void
 procman_save_tree_state (GSettings *settings, GtkWidget *tree, const gchar *child_schema)
 {
     GtkTreeModel *model;
-    GList *it, *columns;
+    GList *columns;
     gint sort_col;
     GtkSortType order;
 
@@ -463,31 +466,6 @@ procman_save_tree_state (GSettings *settings, GtkWidget *tree, const gchar *chil
 
     columns = gtk_tree_view_get_columns (GTK_TREE_VIEW (tree));
 
-    if(!g_strcmp0(child_schema, "proctree"))
-    {
-        for(it = columns; it; it = it->next)
-        {
-            GtkTreeViewColumn *column;
-            gboolean visible;
-            gint width;
-            gchar *key;
-            int id;
-
-            column = static_cast<GtkTreeViewColumn*>(it->data);
-            id = gtk_tree_view_column_get_sort_column_id (column);
-            visible = gtk_tree_view_column_get_visible (column);
-            width = gtk_tree_view_column_get_width (column);
-
-            key = g_strdup_printf ("col-%d-width", id);
-            g_settings_set_int (pt_settings, key, width);
-            g_free (key);
-
-            key = g_strdup_printf ("col-%d-visible", id);
-            g_settings_set_boolean (pt_settings, key, visible);
-            g_free (key);
-        }
-    }
-
     if(!g_strcmp0(child_schema, "proctree") || !g_strcmp0(child_schema, "disktreenew"))
     {
         GSList *order;
@@ -523,9 +501,13 @@ procman_save_config (ProcData *data)
 
     data->config.width  = gdk_window_get_width (gtk_widget_get_window (data->app));
     data->config.height = gdk_window_get_height(gtk_widget_get_window (data->app));
+    gtk_window_get_position(GTK_WINDOW(data->app), &data->config.xpos, &data->config.ypos);
 
     g_settings_set_int (settings, "width", data->config.width);
     g_settings_set_int (settings, "height", data->config.height);
+    g_settings_set_int (settings, "x-position", data->config.xpos);
+    g_settings_set_int (settings, "y-position", data->config.ypos);
+
     g_settings_set_int (settings, "current-tab", data->config.current_tab);
 
     g_settings_sync ();
@@ -713,6 +695,7 @@ main (int argc, char *argv[])
         cb_change_current_page (GTK_NOTEBOOK(procdata->notebook), PROCMAN_TAB_SYSINFO, procdata);
     }
 
+    gtk_widget_set_name(procdata->app, "gnome-system-monitor");
     gtk_widget_show(procdata->app);
 
     procman_debug("begin gtk_main");
